<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
      label-width="100px"
    >
      <el-form-item label="考核对象" prop="unitId">
        <el-select
          v-model="queryParams.unitId"
          @change="handleQuery"
          clearable
          placeholder="考核对象"
        >
          <el-option
            v-for="item in unitList"
            :key="item.id"
            :label="item.value"
            :value="item.id"
          >
          </el-option>
        </el-select>
      </el-form-item>
      <el-form-item label="发布状态" prop="unitId">
        <el-select
          v-model="queryParams.publish"
          @change="handleQuery"
          clearable
          placeholder="发布状态"
        >
          <el-option label="未发布" :value="0" />
          <el-option label="已发布" :value="1" />
        </el-select>
      </el-form-item>
      <el-form-item label="考核时间">
        <el-date-picker
          v-model="daterangeCheckTime"
          style="width: 240px"
          value-format="yyyy-MM-dd HH:mm:ss"
          type="daterange"
          range-separator="-"
          start-placeholder="开始日期"
          end-placeholder="结束日期"
        ></el-date-picker>
      </el-form-item>
      <el-form-item>
        <el-button
          type="primary"
          icon="el-icon-search"
          size="small"
          @click="handleQuery"
          >搜索</el-button
        >
        <el-button icon="el-icon-refresh" size="small" @click="resetQuery"
          >重置</el-button
        >
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <!--      <el-col :span="1.5">-->
      <!--        <el-button-->
      <!--          type="primary"-->
      <!--          plain-->
      <!--          icon="el-icon-plus"-->
      <!--          size="mini"-->
      <!--          @click="handleAdd"-->
      <!--          v-hasPermi="['system:checkResult:add']"-->
      <!--        >新增</el-button>-->
      <!--      </el-col>-->
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          v-hasPermi="['system:result:remove']"
          @click="handleDelete"
          >删除</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          v-hasPermi="['system:result:export']"
          @click="handleExport"
          >导出</el-button
        >
      </el-col>
      <right-toolbar
        :showSearch.sync="showSearch"
        @queryTable="getList"
      ></right-toolbar>
    </el-row>

    <el-row v-loading="loading">
      <el-col
        :xl="8"
        :lg="8"
        :md="12"
        :sm="12"
        :xs="12"
        v-for="(item, index) in checkResultList"
        :key="index"
      >
        <el-card class="box-card">
          <div slot="header" class="clearfix">
            <span>{{ item.contractName }}</span>
            <el-button
              style="float: right; padding: 3px 6px"
              type="text"
              @click="handleDetail(item)"
              >详情</el-button
            >
          </div>
          <div class="text item">
            考核对象<span class="time">{{ item.unitName }}</span>
          </div>
          <div class="text item">
            考核分数<span class="time">{{ item.score }}</span>
          </div>
          <div class="text item">
            考核时间
            <span class="time">{{ item.checkTime }}</span>
            <el-button
              size="small"
              round
              style="float: right"
              @click="handlePublish(item)"
              v-show="item.publish != 1"
              v-hasPermi="['result:contract:publish']"
              >确认发布</el-button
            >
            <el-button
              size="small"
              round
              style="float: right"
              disabled
              v-show="item.publish == 1"
              v-hasPermi="['result:contract:publish']"
              >已发布</el-button
            >
          </div>
        </el-card>
      </el-col>
    </el-row>

    <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <el-dialog
      :title="manualScoreTitle"
      :visible.sync="manualScoreOpen"
      width="500px"
      append-to-body
    >
      <el-input
        v-model="manualScoreForm.manualScore"
        type="number"
        placeholder="请为该单位打分"
      />
      <div slot="footer" class="dialog-footer">
        <el-button @click="cancelManualScore">取 消</el-button>
        <el-button type="primary" @click="submitManualScore">确 定</el-button>
      </div>
    </el-dialog>

    <el-dialog
      :title="detailTitle"
      :visible.sync="detailOpen"
      width="700px"
      append-to-body
    >
      <el-descriptions class="margin-top" :column="3" border>
        <el-descriptions-item>
          <template slot="label">
            <i class="el-icon-user"></i>
            考核对象
          </template>
          {{ detail.unitName }}
        </el-descriptions-item>
        <el-descriptions-item>
          <template slot="label">
            <i class="el-icon-s-management"></i>
            合同名称
          </template>
          {{ detail.contractName }}
        </el-descriptions-item>
        <el-descriptions-item>
          <template slot="label">
            <i class="el-icon-medal"></i>
            综合分数
          </template>
          <el-tag type="danger" size="small">{{ detail.score }}</el-tag>
        </el-descriptions-item>
      </el-descriptions>
      <el-table :data="tableData" show-summary style="width: 100%">
        <el-table-column
          prop="ruleName"
          label="规则名"
          :show-overflow-tooltip="true"
          width="300"
        >
        </el-table-column>
        <el-table-column
          label="扣减方式"
          align="center"
          prop="deductCategory"
          width="180px"
        >
        </el-table-column>
        <el-table-column prop="num" label="量值"> </el-table-column>
        <el-table-column prop="score" label="扣分"> </el-table-column>
      </el-table>
    </el-dialog>

    <!-- 添加或修改考核结果对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button @click="cancel">取 消</el-button>
        <el-button type="primary" @click="submitForm">确 定</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  resultRecord,
  listCheckResult,
  getCheckResult,
  delCheckResult,
  addCheckResult,
  updateCheckResult,
  manualScore,
  publishCheckResult,
} from "@/api/platform/contract-result";
import { unitSelect } from "@/api/platform/unit";

export default {
  name: "CheckResult",
  data() {
    return {
      detailTitle: "",
      detailOpen: false,
      detail: {},
      tableData: [],
      manualScoreOpen: false,
      manualScoreForm: {},
      manualScoreTitle: "",
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 考核结果表格数据
      checkResultList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 逻辑删除时间范围
      daterangeCheckTime: [],
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        checkUnitId: null,
        checkTime: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {},
      unitList: [],
    };
  },
  created() {
    this.getList();
    this.getUnitSelect();
  },
  methods: {
    getUnitSelect() {
      // 运维单位下拉列表
      unitSelect().then((res) => {
        this.unitList = res.data;
      });
    },
    /** 查询考核结果列表 */
    getList() {
      this.loading = true;
      if (null != this.daterangeCheckTime && "" != this.daterangeCheckTime) {
        this.queryParams["createStartTime"] = this.daterangeCheckTime[0];
        this.queryParams["createEndTime"] = this.daterangeCheckTime[1];
      }
      console.log("this.queryParams", this.queryParams);
      listCheckResult(this.queryParams).then((response) => {
        this.checkResultList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        checkUnitId: null,
        checkPublishId: null,
        checkScore: null,
        systemScore: null,
        manualScore: null,
        checkTime: null,
        createTime: null,
        updateTime: null,
        deleted: null,
      };
      this.resetForm("form");
    },
    cancelManualScore() {
      this.manualScoreForm = {};
      this.manualScoreTitle = "";
      this.manualScoreOpen = false;
    },
    submitManualScore() {
      if (!this.manualScoreForm.manualScore) {
        this.$modal.msgWarning("请填写分数");
        return;
      }
      manualScore(this.manualScoreForm).then((res) => {
        this.$modal.msgSuccess("操作成功");
        this.cancelManualScore();
        this.getList();
      });
    },
    handleSetManualScore(row) {
      this.manualScoreForm.id = row.id;
      this.manualScoreForm.manualScore = parseInt(row.manualScore);
      this.manualScoreTitle = row.checkUnitName + "人工打分";
      this.manualScoreOpen = true;
    },
    handleDetail(row) {
      resultRecord(row.id).then((res) => {
        this.tableData = res.rows;
      });
      this.detail = row;
      this.detailTitle = "考核结果详情";
      this.detailOpen = true;
    },
    handlePublish(row) {
      let text = row.publish == 1 ? "取消发布" : "发布";
      const ids = row.id || this.ids;
      this.$modal
        .confirm("是否确认" + text + '考核结果编号为"' + ids + '"的数据项？')
        .then(function () {
          return publishCheckResult(ids);
        })
        .then(() => {
          this.getList();
          this.$modal.msgSuccess(text + "成功");
        })
        .catch(() => {});
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.daterangeCheckTime = [];
      this.resetForm("queryForm");
      this.queryParams = {};
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map((item) => item.id);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加考核结果";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids;
      getCheckResult(id).then((response) => {
        this.form = response.data;
        this.open = true;
        this.title = "修改考核结果";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (this.form.id != null) {
            updateCheckResult(this.form).then((response) => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addCheckResult(this.form).then((response) => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal
        .confirm('是否确认删除考核结果编号为"' + ids + '"的数据项？')
        .then(function () {
          return delCheckResult(ids);
        })
        .then(() => {
          this.getList();
          this.$modal.msgSuccess("删除成功");
        })
        .catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download(
        "check/result/export",
        {
          ...this.queryParams,
        },
        `合同考核结果_${new Date().getTime()}.xlsx`
      );
    },
  },
};
</script>
<style>
.text {
  font-size: 14px;
}
.time {
  font-size: 13px;
  color: #999;
  margin-left: 10px;
}
.item {
  margin-bottom: 18px;
}
.clearfix:before,
.clearfix:after {
  display: table;
  content: "";
}
.clearfix:after {
  clear: both;
}
.box-card {
  width: 400px;
  margin-bottom: 20px;
}
</style>
